==> igniteui-react-core-18.7.0-beta.2.tgz: package/esm5/lib/ToolActionCheckboxListInfo.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { ToolActionInfo } from "./ToolActionInfo";
import { markType } from "./type";
/**
 * @hidden
 */
var ToolActionCheckboxListInfo = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ToolActionCheckboxListInfo, _super);
    function ToolActionCheckboxListInfo() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this._itemsSource = null;
        _this._dataMemberPath = null;
        _this._selectedMemberPath = null;
        _this._primaryKey = null;
        return _this;
    }
    ToolActionCheckboxListInfo.prototype.get_b = function () {
        return 11;
    };
    Object.defineProperty(ToolActionCheckboxListInfo.prototype, "itemsSource", {
        get: function () {
            return this._itemsSource;
        },
        set: function (a) {
            this._itemsSource = a;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(ToolActionCheckboxListInfo.prototype, "dataMemberPath", {
        get: function () {
            return this._dataMemberPath;
        },
        set: function (a) {
            this._dataMemberPath = a;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(ToolActionCheckboxListInfo.prototype, "selectedMemberPath", {
        get: function () {
            return this._selectedMemberPath;
        },
        set: function (a) {
            this._selectedMemberPath = a;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(ToolActionCheckboxListInfo.prototype, "primaryKey", {
        get: function () {
            return this._primaryKey;
        },
        set: function (a) {
            this._primaryKey = a;
        },
        enumerable: false,
        configurable: true
    });
    ToolActionCheckboxListInfo.$t = markType(ToolActionCheckboxListInfo, 'ToolActionCheckboxListInfo', ToolActionInfo.$);
    return ToolActionCheckboxListInfo;
}(ToolActionInfo));
export { ToolActionCheckboxListInfo };

==> igniteui-react-core-18.7.5-beta.2.tgz: package/esm5/lib/ToolActionCheckboxListInfo.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { ToolActionInfo } from "./ToolActionInfo";
import { markType } from "./type";
/**
 * @hidden
 */
var ToolActionCheckboxListInfo = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ToolActionCheckboxListInfo, _super);
    function ToolActionCheckboxListInfo() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this._itemsSource = null;
        _this._dataMemberPath = null;
        _this._selectedMemberPath = null;
        _this._showSelectAll = false;
        _this._primaryKey = null;
        return _this;
    }
    ToolActionCheckboxListInfo.prototype.get_d = function () {
        return 11;
    };
    Object.defineProperty(ToolActionCheckboxListInfo.prototype, "itemsSource", {
        get: function () {
            return this._itemsSource;
        },
        set: function (a) {
            this._itemsSource = a;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(ToolActionCheckboxListInfo.prototype, "dataMemberPath", {
        get: function () {
            return this._dataMemberPath;
        },
        set: function (a) {
            this._dataMemberPath = a;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(ToolActionCheckboxListInfo.prototype, "selectedMemberPath", {
        get: function () {
            return this._selectedMemberPath;
        },
        set: function (a) {
            this._selectedMemberPath = a;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(ToolActionCheckboxListInfo.prototype, "showSelectAll", {
        get: function () {
            return this._showSelectAll;
        },
        set: function (a) {
            this._showSelectAll = a;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(ToolActionCheckboxListInfo.prototype, "primaryKey", {
        get: function () {
            return this._primaryKey;
        },
        set: function (a) {
            this._primaryKey = a;
        },
        enumerable: false,
        configurable: true
    });
    ToolActionCheckboxListInfo.$t = markType(ToolActionCheckboxListInfo, 'ToolActionCheckboxListInfo', ToolActionInfo.$);
    return ToolActionCheckboxListInfo;
}(ToolActionInfo));
export { ToolActionCheckboxListInfo };
